@@ -92,7 +92,7 @@ use PPIx::Regexp::Token::Modifier ();	# For its modifier manipulations.
 use PPIx::Regexp::Util qw{ __instance };
 use Scalar::Util qw{ refaddr };
 
-our $VERSION = '0.036';
+our $VERSION = '0.041';
 
 =head2 new
 
@@ -428,6 +428,13 @@ This method returns true if the given modifier is asserted for the
 regexp, whether explicitly or by the modifiers passed in the
 C<default_modifiers> argument.
 
+Starting with version 0.036_01, if the argument is a
+single-character modifier followed by an asterisk (intended as a wild
+card character), the return is the number of times that modifier
+appears. In this case an exception will be thrown if you specify a
+multi-character modifier (e.g.  C<'ee*'>), or if you specify one of the
+match semantics modifiers (e.g.  C<'a*'>).
+
 =cut
 
 sub modifier_asserted {
@@ -444,6 +451,21 @@ sub modifier_asserted {
 # modifier name, which must not be undef. The return is a boolean.
 *__ducktype_modifier_asserted = \&modifier_asserted;
 
+# As of Perl 5.21.1 you can not leave off the type of a '?'-delimited
+# regexp. Because this is not associated with any single child we
+# compute it here.
+sub perl_version_removed {
+    my ( $self ) = @_;
+    my $v = $self->SUPER::perl_version_removed();
+    defined $v
+	and $v <= 5.021001
+	and return $v;
+    '??' eq $self->delimiters()
+	and '' eq $self->type()->content()
+	and return '5.021001';
+    return $v;
+}
+
 =head2 regular_expression
 
  my $re = PPIx::Regexp->new( 's/(foo)/${1}bar/smx' );
@@ -645,7 +667,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2014 by Thomas R. Wyant, III
+Copyright (C) 2009-2015 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
